@@ -5,7 +5,7 @@
 import logging
 import warnings
 
-from dli.client.components import SirenComponent
+from dli.client.components import SirenComponent, SirenAdapterResponse
 from dli.client.components.urls import autoreg_urls
 from dli.siren import siren_to_entity, siren_to_dict
 
@@ -78,8 +78,10 @@ class AutoRegMetadata(SirenComponent):
 
         payload = {k: v for k, v in fields.items() if v is not None}
         return siren_to_entity(
-            self.session.post(
-                autoreg_urls.autoreg_index, json=payload
+            SirenAdapterResponse(
+                self.session.post(
+                    autoreg_urls.autoreg_index, json=payload
+                )
             ).to_siren()
         )
 
@@ -140,7 +142,7 @@ class AutoRegMetadata(SirenComponent):
             autoreg_urls.autoreg_index, params=kwargs
         )
 
-        return response.to_siren()
+        return SirenAdapterResponse(response).to_siren()
 
     def edit_auto_registration_metadata(
         self,
@@ -215,7 +217,7 @@ class AutoRegMetadata(SirenComponent):
             json=auto_reg_metadata_dict
         )
 
-        return siren_to_entity(response.to_siren())
+        return siren_to_entity(SirenAdapterResponse(response).to_siren())
 
     def delete_auto_registration_metadata(self, auto_reg_metadata_id):
         """
