@@ -2,6 +2,7 @@
 # Copyright (C) 2020 IHS Markit.
 # All Rights Reserved
 #
+import inspect
 import logging
 import warnings
 
@@ -88,35 +89,37 @@ class Dataset(SirenComponent):
                 # if package name is known
                 dataset = client.get_dataset(name='my_dataset', package_name='my_package')
         """
-
-        warnings.warn(
-            'This method is deprecated and is scheduled for removal in '
-            'dli=1.13.0. '
-            '\nTo get a dataset, please use the alternate calls:'
-            '\n'
-            '\n    import dli'
-            '\n    client = dli.connect()'
-            '\n    dataset = client.datasets.get(<dataset shortcode>, Optional:<organisation_short_code>)'
-            '\n'
-            '\nor:'
-            '\n'
-            '\n    import dli'
-            '\n    client = dli.connect()'
-            '\n'
-            '\n    # When you do not know the dataset short code and want to search,'
-            '\n    # then there may be multiple matches returned.'
-            '\n    # Return type: OrderedDict[id: str, DatasetModel]'
-            '\n    datasets = client.datasets(search_term=["name=<dataset_name>"])'
-            '\n'
-            '\nWhen you have found your dataset, then you can perform operations on the '
-            'dataset such as:'
-            '\n'
-            '\n    dataset.partitions()'
-            '\n'
-            '\nFor more details please refer to '
-            'https://supportlibrary.ihsmarkit.com/display/DLSL/Using+a+Dataset',
-            PendingDeprecationWarning
-        )
+        caller = inspect.stack()[2]
+        if caller.function.startswith("<module>") or \
+                ("/dli/tests/" in caller.filename and caller.function.startswith("test_direct")):
+            warnings.warn(
+                'This method is deprecated and is scheduled for removal in '
+                'dli=1.13.0. '
+                '\nTo get a dataset, please use the alternate calls:'
+                '\n'
+                '\n    import dli'
+                '\n    client = dli.connect()'
+                '\n    dataset = client.datasets.get(<dataset shortcode>, Optional:<organisation_short_code>)'
+                '\n'
+                '\nor:'
+                '\n'
+                '\n    import dli'
+                '\n    client = dli.connect()'
+                '\n'
+                '\n    # When you do not know the dataset short code and want to search,'
+                '\n    # then there may be multiple matches returned.'
+                '\n    # Return type: OrderedDict[id: str, DatasetModel]'
+                '\n    datasets = client.datasets(search_term=["name=<dataset_name>"])'
+                '\n'
+                '\nWhen you have found your dataset, then you can perform operations on the '
+                'dataset such as:'
+                '\n'
+                '\n    dataset.partitions()'
+                '\n'
+                '\nFor more details please refer to '
+                'https://supportlibrary.ihsmarkit.com/display/DLSL/Using+a+Dataset',
+                PendingDeprecationWarning
+            )
 
         if dataset_short_code:
             response = self.session.get(
@@ -155,7 +158,7 @@ class Dataset(SirenComponent):
                 dataset_urls.v2_by_id.format(id=id)
             )
 
-        return self.DatasetFactory._from_v2_response(response.json())
+        return self._DatasetFactory._from_v2_response(response.json(), warn=True)
 
     def _get_dataset_id_by_name(self, package_id=None,
                                 dataset_name=None,
@@ -170,7 +173,7 @@ class Dataset(SirenComponent):
                 raise CatalogueEntityNotFoundException("No such package")
 
         ds = self.datasets(search_term=[f"package_id={package_id}",
-                                        f"name={dataset_name}"])
+                                        f"name={dataset_name}"], warn=False)
         try:
             return next(iter(ds.values())).id
         except StopIteration as s:
@@ -206,7 +209,7 @@ class Dataset(SirenComponent):
             },
         ).json()
 
-        return self.DatasetFactory._from_v2_response(result)
+        return self._DatasetFactory._from_v2_response(result)
 
     def edit_dataset(
         self,
@@ -245,6 +248,7 @@ class Dataset(SirenComponent):
         :keyword str data_preview_type: Optional enum of NONE STATIC LIVE. 'NONE' means there is no datapreview. STATIC means
                             to use the file provided. LIVE means to use the latest datafile.
         :keyword file sample_data: Optional file. File like object. Used in conjuntion with data_preview_type. Max size 10Megabytes.
+        :keyword bool details_visible_to_lite_users: Optional. Default value "False".
 
         :returns: Updated Dataset.
         :rtype: Dataset
@@ -287,7 +291,7 @@ class Dataset(SirenComponent):
             }
         ).json()
 
-        return self.DatasetFactory._from_v2_response(result)
+        return self._DatasetFactory._from_v2_response(result)
 
     def delete_dataset(self, dataset_id):
         """
