@@ -43,8 +43,9 @@ class datafile_urls:
 
 
 class me_urls:
+    # '/__api_v2/me/managed_packages'  # Will be changing the endpoint below to the V2 URL
+    # in DLI==1.13.0b3 after Catalogue release 1.40 to Prod.
     my_packages = '/__api/me/my-packages/'
-    consumed_packages = '/__api/me/consumed_packages/'
     my_accounts = '/__api/me/my_accounts/'
 
 
@@ -56,7 +57,7 @@ class package_urls:
     # dli_v2
     v2_package_datasets = '/__api_v2/packages/{id}/datasets'
     v2_package_by_id = '/__api_v2/packages/{id}'
-    v2_package_index = '__api_v2/packages'
+    v2_package_index = '/__api_v2/packages'
 
 
 class search_urls:
