@@ -34,9 +34,7 @@ from dli.models.organisation_model import OrganisationModel
 from dli.client.components.auto_reg_metadata import AutoRegMetadata
 from dli.client.components.datafile import Datafile
 from dli.client.components.dataset import Dataset, Dictionary
-from dli.client.components.me import Me
 from dli.client.components.package import Package
-from dli.client.components.accounts import Accounts
 from dli.client.exceptions import (
     DatalakeException, InsufficientPrivilegesException,
     InvalidPayloadException, UnAuthorisedAccessException,
@@ -60,18 +58,18 @@ from dli.boto_authenticator import BotoAuthenticator
 
 trace_logger = logging.getLogger('trace_logger')
 
-class DliClient(Accounts, AutoRegMetadata,
+class DliClient(AutoRegMetadata,
                 Datafile, Dataset, Dictionary,
-                Me, Package):
+                Package):
     """
     Definition of a client. This client mixes in utility functions for
     manipulating packages, datasets and datafiles.
     """
 
-    DatasetFactory = ModelDescriptor(DatasetFactory)
-    Structured = ModelDescriptor(StructuredDatasetModel)
-    Unstructured = ModelDescriptor(UnstructuredDatasetModel)
-    Instance = ModelDescriptor(InstanceModel)
+    _DatasetFactory = ModelDescriptor(DatasetFactory)
+    _Structured = ModelDescriptor(StructuredDatasetModel)
+    _Unstructured = ModelDescriptor(UnstructuredDatasetModel)
+    _Instance = ModelDescriptor(InstanceModel)
     _InstancesCollection = ModelDescriptor(InstancesCollection_)
     _Pagination = ModelDescriptor(Paginator)
     _File = ModelDescriptor(FileModel)
@@ -166,6 +164,16 @@ class DliClient(Accounts, AutoRegMetadata,
 
 class Session(requests.Session):
 
+    # Full list of possible algorithms:
+    # https://pyjwt.readthedocs.io/en/latest/algorithms.html
+    __pyjwt_algorithms = [
+        # `HS256` is the value returned by the JWT from prod, but pyjwt seems
+        # to complain about the signature.
+        'HS256',
+        'HS512', 'ES256', 'ES384', 'ES512', 'RS256', 'RS384',
+        'RS512', 'PS256', 'PS384', 'PS512',
+    ]
+
     def __init__(
         self, access_id, secret_key, environment, host, logger,
         auth_key=None, auth_prompt=True, use_keyring=True
@@ -219,9 +227,9 @@ class Session(requests.Session):
             "machine but your application credential environment variables "
             "(DLI_ACCESS_KEY_ID and DLI_SECRET_ACCESS_KEY) "
             "are not set or there is no keyring manager available. \n\n"
-            f"YOU MAY NEED TO LOGIN EVERY TIME. \n"
-            f"Please contact support at datalake-support@ihsmarkit.com"
-            f"if you need more help. \n\n"
+            "YOU MAY NEED TO LOGIN EVERY TIME. \n"
+            "Please contact support at datalake-support@ihsmarkit.com "
+            "if you need more help. \n\n"
             f"{str(nke)}\n\n"
         )
         if raises:
@@ -251,7 +259,17 @@ class Session(requests.Session):
         if check_key:
             try:
                 reloaded = check_key
-                decoded = jwt.decode(str.encode(reloaded), verify=False)
+                decoded = jwt.decode(
+                    jwt=str.encode(reloaded),
+                    # `verify` is deprecated in pyjwt 1.5.1, use `options`
+                    # param https://pyjwt.readthedocs.io/en/latest/api.html?
+                    # highlight=verify_signature#jwt.decode
+                    verify=False,
+                    algorithms=self.__pyjwt_algorithms,
+                    options={
+                        "verify_signature": False,
+                    }
+                )
                 if decoded.get("exp", 0) <= time.time():
                     try:
                         keyring.delete_password(__product__,
@@ -425,7 +443,17 @@ class Session(requests.Session):
         )
 
     def _get_decoded_token(self):
-        return jwt.decode(self.auth_key, verify=False)
+        return jwt.decode(
+            jwt=self.auth_key,
+            # `verify` is deprecated in pyjwt 1.5.1, use `options`
+            # param https://pyjwt.readthedocs.io/en/latest/api.html
+            # ?highlight=verify_signature#jwt.decode
+            verify=False,
+            algorithms=self.__pyjwt_algorithms,
+            options={
+                "verify_signature": False,
+            }
+        )
 
     def _get_expiration_date(self):
         default_timeout = (
@@ -505,7 +533,7 @@ class Session(requests.Session):
             isopen=webbrowser.open(url, new=1)
             if not isopen:
                 print(f"WARNING: We could not open a usable web browser for authentication purposes, or alternatively,"
-                      f"Please copy the below:\n\n{url}\n\nEnter this into a web browser that you can access, "
+                      f" please copy the below:\n\n{url}\n\nEnter this into a web browser that you can access, "
                       f"or alternatively, you can use your phone or a web browser on another machine. "
                       f"After this step, by returning here, you will see this console un-blocked.\n"
                       f"If you wish to abort enter Ctrl/Cmd + C on your keyboard.\n\n")
@@ -537,7 +565,9 @@ class Session(requests.Session):
                     "one minute. If this is your first time trying to connect "
                     "and the problem continues then it is possible you have "
                     "a firewall issue (please contact your IT team to "
-                    "check if a firewall rule needs to be added).\n\n"
+                    "check if a firewall rule needs to be added, see "
+                    "https://supportlibrary.ihsmarkit.com/display/DLSL/"
+                    "Firewalls+and+proxies ).\n\n"
                     "Technical details:"
                     f"{e.message}"
                 )
