@@ -15,6 +15,7 @@ class _Environment:
         'catalogue-dev.udpmarkit.net': 'dev',
         'catalogue-qa.udpmarkit.net': 'qa',
         'catalogue-qa2.udpmarkit.net': 'qa2',
+        'catalogue-qa3.udpmarkit.net': 'qa3',
     }
 
     _catalogue_accounts_environment_map = {
@@ -25,6 +26,7 @@ class _Environment:
         'catalogue-dev.udpmarkit.net': 'catalogue-dev.udpmarkit.net',
         'catalogue-qa.udpmarkit.net': 'catalogue-qa.udpmarkit.net',
         'catalogue-qa2.udpmarkit.net': 'catalogue-qa2.udpmarkit.net',
+        'catalogue-qa3.udpmarkit.net': 'catalogue-qa3.udpmarkit.net',
     }
 
     _catalogue_consumption_environment_map = {
@@ -35,6 +37,7 @@ class _Environment:
         'catalogue-dev.udpmarkit.net': 'consumption-dev.udpmarkit.net',
         'catalogue-qa.udpmarkit.net': 'consumption-qa.udpmarkit.net',
         'catalogue-qa2.udpmarkit.net': 'consumption-qa2.udpmarkit.net',
+        'catalogue-qa3.udpmarkit.net': 'consumption-qa3.udpmarkit.net',
     }
 
     _catalogue_sam_environment_map = {
@@ -44,6 +47,7 @@ class _Environment:
         'client-uat.datalake.ihsmarkit.com': 'sam.ihsmarkit.com',
         'catalogue-qa.udpmarkit.net': 'sam.samexternal.net',
         'catalogue-qa2.udpmarkit.net': 'sam.samexternal.net',
+        'catalogue-qa3.udpmarkit.net': 'sam.samexternal.net',
         'catalogue-dev.udpmarkit.net': 'sam.samexternal.net',
     }
 
@@ -54,6 +58,7 @@ class _Environment:
         'client-uat.datalake.ihsmarkit.com': 'datalake-pkce-uat-RMrWmjPhql',
         'catalogue-qa.udpmarkit.net': 'datalake-pkce-sqa-BSFwJUigI4',
         'catalogue-qa2.udpmarkit.net': 'datalake-pkce-sqa-BSFwJUigI4',
+        'catalogue-qa3.udpmarkit.net': 'datalake-pkce-sqa-BSFwJUigI4',
         'catalogue-dev.udpmarkit.net': 'datalake-pkce-dev-sS8hXQiT2m',
     }
 
@@ -64,6 +69,7 @@ class _Environment:
         'client-uat.datalake.ihsmarkit.com': 's3-uat2.datalake.ihsmarkit.com',
         'catalogue-qa.udpmarkit.net': 's3-qa.udpmarkit.net',
         'catalogue-qa2.udpmarkit.net': 's3-qa2.udpmarkit.net',
+        'catalogue-qa3.udpmarkit.net': 's3-qa3.udpmarkit.net',
         'catalogue-dev.udpmarkit.net': 's3-dev.udpmarkit.net',
     }
 
