@@ -1,3 +1,7 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
 import contextlib
 import inspect
 import warnings
@@ -15,7 +19,7 @@ def log_public_functions_calls_using(decorators, class_fields_to_log=None):
         functions_to_exclude = inspect.getmembers(AttributesDict, inspect.isfunction)
         functions_to_decorate = [
             func for func in inspect.getmembers(cls, inspect.isfunction)
-            if func not in functions_to_exclude and not func[0].startswith('__')
+            if func not in functions_to_exclude and not func[0].startswith('_') and not func[0].startswith('__')
         ]
         for function_meta in functions_to_decorate:
             function_name = function_meta[0]
@@ -50,15 +54,72 @@ class SampleData:
     @contextlib.contextmanager
     def file(self):
         """
-        Provides a file like object containing sample data.
+        Get the sample data.
+        The response type varies depending on whether the dataset is setup to return a static
+        preview or a live preview.
+        If the preview type is a static preview, then this function provides a file like object
+        containing sample data.
 
-        Example usage:
+        Example usage for static preview of a .parquet format file:
 
         .. code-block:: python
 
-            dataset = self.client.get_dataset(dataset_id)
+            import pandas
+            import dli
+
+            client = dli.connect()
+
+            dataset = client.datasets.get('some-dataset-short-code')
+
+            with dataset.sample_data.file() as f:
+                dataframe = pandas.read_parquet(f)
+
+        Example usage for static preview of a .csv format file:
+
+        .. code-block:: python
+
+            import pandas
+            import dli
+
+            client = dli.connect()
+
+            dataset = client.datasets.get('some-dataset-short-code')
+
             with dataset.sample_data.file() as f:
                 dataframe = pandas.read_csv(f)
+
+        Else if the preview type is a live preview, then this function provides a HTTP response
+        that needs to be wrapped for pandas to be able to read
+
+        Example usage for live preview of a .parquet format file:
+
+        .. code-block:: python
+
+            import pandas
+            import dli
+            import io
+
+            client = dli.connect()
+
+            dataset = client.datasets.get('some-dataset-short-code')
+
+            with dataset.sample_data.file() as f:
+                dataframe = pd.read_parquet(io.BytesIO(f.read()))
+
+        Example usage for live preview of a .parquet format file:
+
+        .. code-block:: python
+
+            import pandas
+            import dli
+            import io
+
+            client = dli.connect()
+
+            dataset = client.datasets.get('some-dataset-short-code')
+
+            with dataset.sample_data.file() as f:
+                dataframe = pd.read_csv(io.BytesIO(f.read()))
         """
         response = self._client.session.get(
             dataset_urls.v2_sample_data_file.format(id=self._parent.id),
@@ -97,14 +158,6 @@ class AttributesDict(UserDict):
     def __len__(self):
         return len(self.__dict__)
 
-    def _asdict(self, *args, **kwargs):
-        warnings.warn(
-            'This method is deprecated as it returns itself.',
-            DeprecationWarning
-        )
-
-        return self
-
     def __repr__(self):
         attributes = ' '.join([
             '{}={}'.format(k, v) for k,v in self.__dict__.items()
