@@ -4,18 +4,16 @@
 #
 import os
 import uuid
-import warnings
 from abc import ABCMeta
-from typing import List, Optional, Callable, Tuple
+from typing import List, Optional, Callable, Tuple, Iterator
 
-import s3transfer
 from tqdm import tqdm
 
+import boto3.s3.transfer
 
-from s3transfer.manager import TransferManager, TransferConfig
-import boto3.s3.transfer as s3transfer
-
-from dli.aws import create_refreshing_session, trace_logger
+from dli.aws import create_refreshing_session, trace_logger, \
+    is_hidden_file, get_s3_list, get_s3_list_filter_out_hidden, \
+    get_most_recent_common_prefix
 from dli.client import utils
 from dli.models import AttributesDict
 from dli.models.file_model import get_or_create_os_path
@@ -37,16 +35,23 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
 
     def _check_access(self):
         if not self.has_access:
+            # Link to the package page in the Catalogue UI where the user
+            # can request access.
+            # eg. https://catalogue.datalake.ihsmarkit.com/package/
+            # 7eddd22c-2b3c-11eb-9dd7-f64fac425b13
+            package_url = f'{self._client._environment.catalogue}/' \
+                          f'package/{self.package_id}'
             raise Exception(
-                'Unfortunately the user you are using '
-                'does not have access to this dataset. '
-                'Please request access to the package/dataset '
-                "to be able to retrieve this content."
+                'You require access to this package to retrieve its content. '
+                f'To request access, please visit {package_url}'
             )
 
     @staticmethod
     def _get_transfer_manager(s3_client, config):
-        return TransferManager(s3_client, config=config)
+        return boto3.s3.transfer.create_transfer_manager(
+            client=s3_client,
+            config=config,
+        )
 
     @property
     def id(self):
@@ -239,57 +244,45 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
         if filter_path:
             filter_prefix = filter_prefix + filter_path.lstrip('/')
 
-        def _to_s3_proxy_path_and_size(object_summary) -> (str, int):
-            if absolute_path:
-                return (f"s3://{self.organisation_short_code}/" \
-                       f"{object_summary.key}", object_summary.size)
-            else:
-                return (object_summary.key, object_summary.size)
-
-        # Convert each object_summary into an S3 proxy path.
-        object_summaries = [
-            object_summary for object_summary in bucket.objects.filter(
-                # Prefix searches for exact matches and folders
-                Prefix=filter_prefix
+        if filter_path is None and skip_hidden_files:
+            paths: List[Tuple[str, int]] = list(
+                get_s3_list_filter_out_hidden(
+                    resource=s3_resource,
+                    bucket=bucket,
+                    prefix=filter_prefix,
+                    content_type=self.content_type,
+                    load_type=self.load_type,
+                    absolute_path=absolute_path,
+                    organisation_short_code=self.organisation_short_code,
+                )
             )
-        ]
+        else:
+            # The user provided an explicit filter_path so give the
+            # user the S3 list under that path. There is no need to do common
+            # prefix filtering as the filter_path will point us to a folder
+            # not in the top-level of the dataset (where the .hidden
+            # directories usually appear).
+            paths: List[Tuple[str, int]] = list(get_s3_list(
+                bucket=bucket,
+                prefix=filter_prefix,
+                absolute_path=absolute_path,
+                organisation_short_code=self.organisation_short_code,
+            ))
 
         trace_logger.info(
             "Number of paths on S3 for this dataset: "
-            f"'{len(object_summaries)}'"
+            f"'{len(paths)}'"
         )
 
-        # Convert each object_summary into an S3 proxy path.
-        paths: List[Tuple[str, int]] = [
-            _to_s3_proxy_path_and_size(object_summary) for object_summary in
-            object_summaries if not object_summary.key.endswith('/')
-        ]
-
         if skip_hidden_files:
-            # [DL-4545][DL-4536][DL-5209] Do not read into files or
-            # directories that are cruft from Spark which Spark will ignore
-            # on read, e.g. files/dirs starting with `.` or `_` are hidden
-            # to Spark.
-
-            # Skip as_of_*=latest as it is a Spark temporary folder.
-
-            def is_hidden_file(path: str):
-                return (
-                    path.startswith('.') or
-                    path.startswith('_') or
-                    (
-                        path == 'metadata' and
-                        self.content_type != "Unstructured"
-                    ) or
-                    (
-                        path.startswith('as_of_') and
-                        path.endswith('=latest')
-                    )
-                )
-
+            # Although we have skipped hidden files in the top-level, there
+            # could be files under the prefix e.g. sometimes there are Spark
+            # _SUCCESS files mixed in with the data at the leaf level of the
+            # S3 tree.
             paths: List[Tuple[str, int]] = [
                 path for path in paths
-                if not any(is_hidden_file(split) for split in path[0].split('/'))
+                if not any(is_hidden_file(split, self.content_type)
+                           for split in path[0].split('/'))
             ]
 
             trace_logger.info(
@@ -300,8 +293,8 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
         if custom_filter_func:
             len_before = len(paths)
             trace_logger.info(
-                f'Filtering {len_before} paths according to '
-                f'{custom_filter_func} logic.'
+                f'Filtering {len_before} paths according to this dataset '
+                f"type's custom filter logic."
             )
 
             paths = custom_filter_func(paths=paths)
@@ -385,13 +378,21 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
         GB = KB * KB * KB
         multipart_threshold = 500 * GB
 
+        # Use an environment variable to disable the entire progressbar
+        # wrapper. This can be necessary for monitors where the bar will not
+        # be correctly formatted in DataDog.
+        disable_progress_bar = \
+            True if os.environ.get('DLI_DISABLE_PROGRESS_BAR', '').lower() \
+            == 'true' else False
+
         progress = tqdm(
             desc='Downloading ',
             total=sum(sizes), unit='B', unit_scale=1,
             position=0,
+            disable=disable_progress_bar,
         )
 
-        config = TransferConfig(
+        config = boto3.s3.transfer.TransferConfig(
             multipart_threshold=multipart_threshold,
         )
 
@@ -403,6 +404,12 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
         warns = []
         with transfer_manager_context as transfer_manager:
             with progress as pbar:
+                # Create progress_callback outside of the loop.
+                progress_callback = boto3.s3.transfer.ProgressCallbackInvoker(
+                    pbar.update
+                )
+                subscribers = [progress_callback]
+
                 _paths_and_futures = []
 
                 for path in paths:
@@ -426,7 +433,7 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
                             self.organisation_short_code,
                             path,
                             to_path,
-                            subscribers=[s3transfer.ProgressCallbackInvoker(pbar.update)]
+                            subscribers=subscribers,
                         )
 
                         _paths_and_futures.append((to_path, future))
@@ -483,3 +490,11 @@ class DatasetModel(AttributesDict, metaclass=ABCMeta):
         :return: Prints the metadata.
         """
         utils.print_model_metadata(self)
+
+    def package(self):
+        """
+        Returns the parent package of this dataset based on the package_id stamped onto the dataset.
+
+        # note there is no typing on this method to avoid a circular referencing.
+        """
+        return list(self._client.packages(search_term=f"package_id={self.package_id}").values())[0]
\ No newline at end of file
