@@ -1,3 +1,7 @@
+#
+# Copyright (C) 2020 IHS Markit.
+# All Rights Reserved
+#
 import math
 from concurrent.futures.thread import ThreadPoolExecutor
 from threading import Lock
@@ -8,8 +12,10 @@ class Paginator:
     def __init__(self, url, model,
          instantiation_method=None, instantiation_override=None,
          page=1, total_field=None, page_size=25, max_workers=10,
+         filters=None
     ):
         self.page = page
+        self.filters = filters
         self.page_size = page_size
         self.url = url
         self.model = model
@@ -26,13 +32,19 @@ class Paginator:
             'page': self.page if not page else page,
         }
 
+        if self.filters and type(self.filters) is dict:
+            params.update(self.filters)
+
+
         if self.page_size:
             params['page_size'] = self.page_size
 
-        return self.model._client.session.get(
+        s = self.model._client.session.get(
             self.url,
             params=params
-        ).json()
+        )
+
+        return s.json()
 
     def __iter__(self):
         if not self.cache:
@@ -93,7 +105,7 @@ class Paginator:
                 if not self.instantiation_factory:
                     m = self.model(f)
                 else:
-                    m = self.instantiation_factory(f)
+                    m = self.instantiation_factory(f, page_size=self.page_size)
 
                 with self.lock:
                     self.cache.append(m)
