@@ -21,12 +21,12 @@ class UnstructuredDatasetModel(DatasetModel):
 
         if "warn" in kwargs:
             warn = kwargs.pop('warn')
-            if warn:
-                self._client.logger.warning(
-                    "WARN: This is an Unstructured dataset.\n"
-                    "Available methods and method arguments may differ, "
-                    "please see the documentation."
-                )
+            # if warn:
+            #     self._client.logger.warning(
+            #         "WARN: This is an Unstructured dataset.\n"
+            #         "Available methods and method arguments may differ, "
+            #         "please see the documentation."
+            #     )
         super().__init__(**kwargs, )
 
     class __DeferInCaseCall(object):
@@ -217,7 +217,7 @@ class UnstructuredDatasetModel(DatasetModel):
         self,
         request_id=None,
         absolute_path: bool = True,
-        skip_hidden_files: bool = True,
+        skip_hidden_files: bool = False,
     ) -> List[str]:
         """
         List all the paths to files in the dataset. Calls go via the
