@@ -143,69 +143,6 @@ class DatasetTestCase(SdkIntegrationTestCase):
                 dataset_short_code='testdatasetfunctions', organisation_short_code='abc'
             )
 
-    def test_can_get_dataset_by_id_or_name(self):
-        builder = self.builder.with_external_storage(
-            location="jdbc://connectionstring:1232/my-db"
-        )
-        package = self.client.get_package(id=self.package_id)
-        expected = self.client.register_dataset(builder)
-        actual = self.client.get_dataset(expected.dataset_id)
-
-        self.assertEqual(expected.dataset_id, actual.dataset_id)
-
-        # By id
-        dataset_by_id = self.client.get_dataset(id=expected.dataset_id)
-        self.assertEqual(expected.dataset_id, dataset_by_id.dataset_id)
-
-        # By name and package id
-        dataset_by_name_and_package_id = self.client.get_dataset(name=expected.name, package_id=package.id)
-        self.assertEqual(expected.dataset_id, dataset_by_name_and_package_id.dataset_id)
-
-        # By name and package name
-        dataset_by_name_and_package_name = self.client.get_dataset(name=expected.name, package_name=package.name)
-        self.assertEqual(expected.dataset_id, dataset_by_name_and_package_name.dataset_id)
-
-        # By name and package name and package id
-        dataset_by_name_and_package_name_and_id = self.client.get_dataset(name=expected.name,
-                                                                          package_id=package.id,
-                                                                          package_name=package.name)
-        self.assertEqual(expected.dataset_id, dataset_by_name_and_package_name_and_id.dataset_id)
-
-        # By bad dataset name, valid package name
-        with self.assertRaises(Exception):
-            dataset_by_baddataset_name = self.client.get_dataset(
-                name="bad name",
-                package_id=package.package_id,
-                package_name=package.name)
-
-        # By dataset name, invalid package name
-        with self.assertRaises(Exception):
-            dataset_by_badpackage_name = self.client.get_dataset(
-                name=expected.name,
-                package_name="bad name")
-
-        # No package deets
-        with self.assertRaises(Exception):
-            dataset_by_name_no_package = self.client.get_dataset(
-                name="bad name")
-
-        # No dataset deets
-        with self.assertRaises(Exception):
-            dataset_by_package_name_no_dataset = self.client.get_dataset(
-                package_name="bad")
-
-
-    def test_cannot_get_dataset_by_name_if_package_id_and_package_name_mismatch(self):
-        builder = self.builder.with_external_storage(
-            location="jdbc://connectionstring:1232/my-db"
-        )
-        package = self.client.get_package(id=self.package_id)
-        dataset = self.client.register_dataset(builder)
-
-        with self.assertRaises(CatalogueEntityNotFoundException):
-            self.client.get_dataset(name=dataset.name, package_id=package.id, package_name="unknown")
-            self.client.get_dataset(name=dataset.name, package_id="unknown", package_name=package.name)
-
     def test_retrieve_keys_for_unknown_dataset_raises_error(self):
         with self.assertRaises(CatalogueEntityNotFoundException):
             self.client.get_s3_access_keys_for_dataset("unknown")
