@@ -6,7 +6,7 @@ def test_existing_requirements(session):
     session.install('-r', '../../requirements.txt')
     session.install('-r', '../../requirements-test.txt')
     os.chdir('../../')
-    session.run('pytest')
+    session.run('pytest', '-m', 'not integration', '--verbose')
 
 
 def test_requirements_sc0(session):
@@ -14,11 +14,11 @@ def test_requirements_sc0(session):
         Smoke test - single unittest, no integration tests.
         Integration tests are run in test_requirements_offset_scenarios.
     """
-    TEST_FILES = ['../models/test_structured_dataset.py', ]
+    TEST_FILES = ['./tests/models/test_structured_dataset.py']
     session.install('-r', '../../requirements.txt')
     session.install('-r', '../../requirements-test.txt')
     os.chdir('../../')
-    session.run('pytest', '-m', "'not integration'", *TEST_FILES)
+    session.run('pytest', '-m', "'not integration'", '--verbose', *TEST_FILES)
 
 
 def test_requirements_offset_scenarios(session):
@@ -33,6 +33,7 @@ def test_requirements_offset_scenarios(session):
     install_betas: bool = os.environ.get('INSTALL_BETAS', None) == 'True'
 
     if scenario == '1':
+        print('Not using a min_date')
         min_date = None
     from_file = '../../requirements.txt'
     to_file = f'requirements-{scenario}.txt'
@@ -40,20 +41,34 @@ def test_requirements_offset_scenarios(session):
     rm = RequirementsModifier(from_file)
     rm.modify_requirements(from_file, to_file, min_date)
     if install_betas:
+        print('Install beta versions of dependencies')
         session.install('-r', f'requirements-{scenario}.txt', '--pre')
         session.install('-r', '../../requirements-test.txt', '--pre')
     else:
+        print('Install release versions of dependencies')
+        # TODO scott: a bit of tech debt - we didn't need to write to a file,
+        #  doing a session.install you can install a dependency just like
+        #  you would with pip. So instead of adding a line to a file, just
+        #  session install and print what version and date you are using and
+        #  the command line will print the result of the install anyway).
         session.install('-r', f'requirements-{scenario}.txt')
         session.install('-r', '../../requirements-test.txt')
+
+    session.run('pip', 'list', '--format', 'columns')
     os.chdir('../../')
-    session.run('pytest')
+    session.run('pytest', '-m', 'not integration', '--verbose')
 
 
-PYTHON_VERSIONS_LIST = ['3.6', '3.7']
-PIP_VERSIONS_LIST = ['9.0.0', '20.1.1']
-
-PYTHON_38 = ['3.8']
-PIP_20 = ['20.1.1']
+PYTHON_VERSIONS_LIST = [
+    '3.6.10',
+    '3.7',
+    '3.8.1',
+    # '3.9.1', # Not yet supported by Pyarrow
+]
+PIP_VERSIONS_LIST = [
+    '19.0',  # Oldest pip working with pyarrow 3.0.0. 22nd January 2019.
+    '21.0.1',  # Latest pip on 30th January 2021.
+]
 
 
 def test(session, pip_version):
@@ -63,10 +78,6 @@ def test(session, pip_version):
         '0': test_requirements_sc0,
         '1': test_requirements_offset_scenarios,
         '2': test_requirements_offset_scenarios,
-        '3': test_requirements_offset_scenarios,
-        '4': test_requirements_offset_scenarios,
-        '5': test_requirements_offset_scenarios,
-        '6': test_requirements_offset_scenarios,
     }
     scenario = os.environ.get('NOX_SCENARIO')
     print('NOX_SCENARIO=', scenario)
@@ -79,15 +90,17 @@ def test(session, pip_version):
 @nox.session(python=PYTHON_VERSIONS_LIST)
 @nox.parametrize('pip_version', PIP_VERSIONS_LIST)
 def test_python36_python37(session, pip_version):
+    min_date = os.environ.get('MIN_DATE')
+    if session.python == '3.8.1' and min_date <= '2020-02-01':
+        print(
+            'Skip as Python 3.8.1 was not supported by our dependencies before'
+            f'this date. Python {session.python}, min_date {min_date}'
+        )
+        session.skip()
+
     test(session, pip_version)
 
 
-# @nox.session(python=PYTHON_38)
-# @nox.parametrize('pip_version', PIP_20)
-# def test_python38(session, pip_version):
-#     test(session, pip_version)
-
-
 class RequirementsModifier:
 
     def __init__(self, from_file):
@@ -113,25 +126,47 @@ class RequirementsModifier:
         # these constraints should be added to requirements.txt
         # if they help avoid versioning error
 
+        # These are the earliest versions of the dependencies that we can
+        # support e.g. we cannot support numpy below `1.16.0rc1` because
+        # pandas would not be compatible.
         # package<version
         self.version_limits = {
-            'pyarrow': '0.11.1',
-            'python-dateutil': '2.7.0',
-            'pandas': '0.25.3',
-            'keyring': '17.1.1',
-            'pyhumps': '0.5.1',
-            'python-json-logger': '0.1.10',
+            'numpy': '1.16.0rc1',  # 2018-12-20
+            'Flask': '1.0.2',  # 2018-05-02
+            'pyarrow': '0.11.1',  # 2018-10-24
+            'keyring': '17.1.1',  # 2018-12-23
+            'pypermedia': '0.4.2',  # 2016-02-18
+            'python-json-logger': '0.1.10',  # 2018-11-07
+            'requests': '2.22.0',  # 2019-05-16
+            'deprecated': '1.2.4',  # 2019-05-16
+            'tqdm': '4.28.1',  # 2018-10-21
+            'pyjwt': '1.7.1',  # 2018-12-07
+            'requests-toolbelt': '0.8.0',  # 2017-05-20
+            'pandas': '0.25.3',  # 2019-11-01
+            'tabulate': '0.8.2',  # 2017-11-26
+            'pyhumps': '0.5.1',  # 2018-10-30
+            'wrapt': '1.10.11',  # 2017-08-11
+            'ipywidgets': '7.4.2',  # 2018-09-14
+            'ipython': '7.2.0',  # 2018-11-30
+            'python-dateutil': '2.7.5',  # 2018-10-27
+            's3transfer': '0.1.13',  # 2018-02-15
             # IPV6_ADDRZ_RE should be available in urllib3 1.25.4 forward
             # which is the lowest version of the library botocore supports.
             # https://github.com/boto/botocore/issues/2186#issuecomment-712449171
-            'urllib3': '1.25.4',
+            'urllib3': '1.25.4',  # 2019-05-02
+            'botocore': '1.12.156',  # 2019-05-04 Allows urllib 1.25.4
+            'boto3': '1.9.71',  # 2018-12-21
+            'boto': '2.49.0',  # 2018-07-11
         }
 
         # package==version
         self.version_override = {}
 
+        # Ignore these versions as they have breakages e.g. numpy `1.20.0rc1`
+        # is not compatible with pyarrow/pandas released at the same time.
         # package!=version
         self.version_omit = {
+            'numpy': '1.20.0rc2',
             'pyarrow': '0.13.0',
         }
 
@@ -199,6 +234,7 @@ class RequirementsModifier:
             f.writelines(reqs)
 
     def print_requirements_diff(self):
+        print('requirements diff:')
         rlen = len(self.altered_reqs)
         r = 0
         while r < rlen:
@@ -260,16 +296,21 @@ class RequirementsModifier:
                 alt_vrsn, alt_date = smaller()
 
             # Apply temporary nox testing constraints
-            # 1. check if req has a known issue / limit in version number for nox tests
+            # 1. check if req has a known issue / limit in version number for
+            # nox tests
             if (self.package in self.version_limits and
                     version.parse(alt_vrsn) < version.parse(self.version_limits[self.package])):
                 alt_vrsn = self.version_limits[self.package]
                 alt_date = self.version_to_date[alt_vrsn]
 
             # 2. override modification to specific version
-            if (self.package in self.version_override):
+            if self.package in self.version_override:
                 alt_vrsn = self.version_override[self.package]
                 alt_date = self.version_to_date[alt_vrsn]
+                print(
+                    'override modification to specific version. '
+                    f'alt_vrsn {alt_vrsn}, alt_date {alt_date}'
+                )
 
             # 3. for pckg!=version find an earlier version number
             if (self.package in self.version_omit and
@@ -280,7 +321,8 @@ class RequirementsModifier:
             return alt_vrsn, alt_date
 
         def skip_modification():
-            # skip modification and check existing version in requirements.txt is valid for ==
+            # skip modification and check existing version in requirements.txt
+            # is valid for ==
             # not all ~=versionA would work with ==versionA!
             try:
                 alt_date = self.version_to_date[self.current_version]
@@ -378,7 +420,16 @@ class RequirementsModifier:
             # II. Do modification to package version.
             self.passed_constraints = False
             alt_vrsn, alt_date = self.find_acceptable_version(cntr_dict)
-            self.altered_reqs.append(f'{self.package}=={alt_vrsn}    # {alt_date[:10]}\n')
+
+            if self.min_date is None:
+                if self.package in self.version_omit:
+                    # Edge case where we are testing betas and we find that
+                    # a beta causes a problem so we neeed to exclude it.
+                    self.altered_reqs.append(f'{self.package}>={alt_vrsn},!={self.version_omit[self.package]}    # {alt_date[:10]}\n')
+                else:
+                    self.altered_reqs.append(f'{self.package}>={alt_vrsn}    # {alt_date[:10]}\n')
+            else:
+                self.altered_reqs.append(f'{self.package}=={alt_vrsn}    # {alt_date[:10]}\n')
 
         # III. write modified requirements to file for nox testing
         self.write_requirements(self.altered_reqs, to_file)
