@@ -7,20 +7,20 @@ from freezegun import freeze_time
 from moto import mock_s3
 
 from dli.aws import create_refreshing_session, _meets_partition_params, \
-    match_partitions, filter_by_load_type_full
+    match_partitions, get_most_recent_common_prefix
 
 path_with_as_of_date = 'prefix/a=2/b=4/c=6/as_of_date=2020-01-23/file.ext'
 path_with_as_of_year_month = 'prefix/a=2/b=4/c=6/' \
                              'as_of_year_month=2020-01/file.ext'
 paths_and_sizes = [
-    ('prefix/as_of_date=2020-01-01/file0.ext', 1),
-    ('prefix/as_of_date=2020-01-02/file1.ext', 1),
-    ('prefix/as_of_date=2020-01-03/file2.ext', 1),
-    ('prefix/as_of_date=2020-01-03/file3.ext', 1),
+    'prefix/as_of_date=2020-01-01/file0.ext',
+    'prefix/as_of_date=2020-01-02/file1.ext',
+    'prefix/as_of_date=2020-01-03/file2.ext',
+    'prefix/as_of_date=2020-01-03/file3.ext',
 ]
 paths_without_as_of = [
-    ('prefix/file0.ext', 1),
-    ('prefix/file1.ext', 1),
+    'prefix/file0.ext',
+    'prefix/file1.ext',
 ]
 
 
@@ -335,42 +335,25 @@ def test_false_when_as_of_date_is_invalid():
     assert not _meets_partition_params(invalid_path, partition_query)
 
 
-def test_load_type_none_returns_data_from_all_as_of_dates():
-    assert filter_by_load_type_full(
-        paths=paths_and_sizes,
-        load_type=None) == paths_and_sizes
-
-
-def test_load_type_incremental_returns_data_from_all_as_of_dates():
-    assert filter_by_load_type_full(
-        paths=paths_and_sizes,
-        load_type='Incremental Load'
-    ) == paths_and_sizes
-
-
 def test_load_type_full_returns_data_from_most_recent_as_of_date():
-    assert filter_by_load_type_full(
-        paths=paths_and_sizes,
-        load_type='Full Load'
+    assert get_most_recent_common_prefix(
+        common_prefixes=paths_and_sizes,
     ) == paths_and_sizes[-2:]
 
 
 def test_load_type_full_but_zero_paths_returns_empty():
-    assert filter_by_load_type_full(
-        paths=[],
-        load_type='Full Load'
+    assert get_most_recent_common_prefix(
+        common_prefixes=[],
     ) == []
 
 
 def test_load_type_full_all_paths_without_as_of_date_return_paths():
-    assert filter_by_load_type_full(
-        paths=paths_without_as_of,
-        load_type='Full Load'
+    assert get_most_recent_common_prefix(
+        common_prefixes=paths_without_as_of,
     ) == paths_without_as_of
 
 
 def test_load_type_full_some_paths_without_as_of_date_return_paths():
-    assert filter_by_load_type_full(
-        paths=paths_and_sizes + paths_without_as_of,
-        load_type='Full Load'
+    assert get_most_recent_common_prefix(
+        common_prefixes=paths_and_sizes + paths_without_as_of,
     ) == paths_and_sizes[-2:]
