@@ -30,9 +30,19 @@ from dli.siren import PatchedSirenBuilder
 
 environ = MagicMock(catalogue='http://catalogue.local',
                     accounts='')
-valid_token = jwt.encode({"exp": 9999999999}, 'secret')
-expired_token = jwt.encode({"exp": 1111111111}, 'secret')
-long_token = jwt.encode({"exp": 9999999999, "accounts": ["test"]*1000}, 'secret')
+
+
+def _get_token(payload, secret: str) -> str:
+    token_encoded = jwt.encode(payload, secret)
+    if isinstance(token_encoded, bytes):
+        return token_encoded.decode('utf-8')
+    else:
+        return token_encoded
+
+
+valid_token: str = _get_token({"exp": 9999999999}, 'secret')
+expired_token: str = _get_token({"exp": 1111111111}, 'secret')
+long_token: str = _get_token({"exp": 9999999999, "accounts": ["test"]*1000}, 'secret')
 
 
 class SessionTestCase(unittest.TestCase):
@@ -358,7 +368,7 @@ def real_drive(port, postbox, env):
 
 
 def test_reload_JWT_keyring(monkeypatch):
-    monkeypatch.setattr(keyring, 'get_password', lambda _, app: valid_token.decode())
+    monkeypatch.setattr(keyring, 'get_password', lambda _, app: valid_token)
 
     dl = UnitTestClientMockWithAuth(api_root="Test")
     dl._session._get_web_auth_key = MagicMock()
@@ -367,12 +377,12 @@ def test_reload_JWT_keyring(monkeypatch):
 
 
 def test_reload_long_JWT_keyring(monkeypatch):
-    monkeypatch.setattr(keyring, 'get_password', lambda _, app: long_token.decode())
+    monkeypatch.setattr(keyring, 'get_password', lambda _, app: long_token)
 
     dl = UnitTestClientMockWithAuth(api_root="Test")
     dl._session._get_web_auth_key = MagicMock()
     dl._session._auth_init()
-    assert dl._session.auth_key.encode("utf-8") == long_token
+    assert dl._session.auth_key == long_token
     assert dl._session._get_web_auth_key.call_count == 0
 
 
@@ -426,7 +436,7 @@ def test_store_long_long_keyring(monkeypatch, caplog):
 
     def catch(port, postbox):
         dl._session.get = MagicMock()
-        dl._session.get.return_value = Mock(status_code=200, text=valid_token.decode("utf-8"), content="test")
+        dl._session.get.return_value = Mock(status_code=200, text=valid_token, content="test")
 
     dl._session._get_web_auth_key(callback=catch)
     # n.b we are gonna get this, but because we play with os.name
@@ -435,7 +445,7 @@ def test_store_long_long_keyring(monkeypatch, caplog):
     assert len(tk.dic.keys()) == 2
 
     assert tk.dic["ihsm-datalakehttp://catalogue.local"] == "**split**1"
-    assert tk.dic["ihsm-datalakehttp://catalogue.local-0"].encode("utf-8") == valid_token
+    assert tk.dic["ihsm-datalakehttp://catalogue.local-0"] == valid_token
 
 
 @patch("os.name","nt")
@@ -470,7 +480,7 @@ def test_store_long_long_keyring_split(monkeypatch, caplog):
 
     def catch(port, postbox):
         dl._session.get = MagicMock()
-        dl._session.get.return_value = Mock(status_code=200, text=long_token.decode("utf-8"), content="test")
+        dl._session.get.return_value = Mock(status_code=200, text=long_token, content="test")
 
     dl._session._get_web_auth_key(callback=catch)
     # n.b we are gonna get this, but because we play with os.name
@@ -480,7 +490,7 @@ def test_store_long_long_keyring_split(monkeypatch, caplog):
 
     assert tk.dic["ihsm-datalakehttp://catalogue.local"] == "**split**10"
     for x in range(int(tk.dic["ihsm-datalakehttp://catalogue.local"].split("**split**")[-1])):
-        assert tk.dic[f"ihsm-datalakehttp://catalogue.local-{x}"].encode("utf-8") == \
+        assert tk.dic[f"ihsm-datalakehttp://catalogue.local-{x}"] == \
                long_token[x*1000:((1+x)*1000)]
 
 def test_no_reload_delete_expired_JWT_keyring(monkeypatch):
@@ -488,10 +498,10 @@ def test_no_reload_delete_expired_JWT_keyring(monkeypatch):
     dl = UnitTestClientMockWithAuth(api_root="Test")
     # we definitely set it in the first place
     keyring.set_password(
-        __product__, dl._session._environment.catalogue, valid_token.decode())
+        __product__, dl._session._environment.catalogue, valid_token)
     # later 'expires'
     orig = keyring.get_password
-    monkeypatch.setattr(keyring, 'get_password', lambda _, app: expired_token.decode())
+    monkeypatch.setattr(keyring, 'get_password', lambda _, app: expired_token)
 
     dl._session._get_web_auth_key = MagicMock()
     dl._session._get_web_auth_key.return_value = valid_token
@@ -509,11 +519,11 @@ def test_set_JWT_keyring_web_auth_key(monkeypatch):
 
     def catch(port, postbox):
         dl._session.get = MagicMock()
-        dl._session.get.return_value = Mock(status_code=200, text=valid_token.decode("utf-8"), content="test")
+        dl._session.get.return_value = Mock(status_code=200, text=valid_token, content="test")
 
     dl._session._get_web_auth_key(callback=catch)
     assert(orig(__product__, dl._session._environment.catalogue)
-           == valid_token.decode())
+           == valid_token)
 
 
 @pytest.mark.xfail
@@ -589,8 +599,7 @@ def test_no_system_keyring_installed(monkeypatch):
 
 def test_no_system_keyring_ack(monkeypatch, capsys):
     keyring.core.set_keyring(keyring.core.fail.Keyring())
-    a = Mock(status_code=200, text=valid_token.decode("utf-8"),
-                          content="test")
+    a = Mock(status_code=200, text=valid_token, content="test")
 
     def t(pb):
         return a
